Clazz.declarePackage("JV");
(function(){
var c$ = Clazz.declareType(JV, "JmolStateCreator", null);
})();
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
